@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -87,10 +87,12 @@ MIDI::RtController::Filter::Drums - RtController drum filters
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
+  use curry;
+  use Future::IO::Impl::IOAsync;
   use MIDI::RtController ();
   use MIDI::RtController::Filter::Drums ();
 
@@ -98,7 +100,7 @@ version 0.0101
 
   my $rtf = MIDI::RtController::Filter::Drums->new(rtc => $rtc);
 
-  $rtc->add_filter('foo', note_on => $rtf->can('foo'));
+  $rtc->add_filter('drums', note_on => $rtf->curry::drums);
 
   $rtc->run;
 
